SystemOrganization addCategory: #'WebStore-Core'!
SystemOrganization addCategory: #'WebStore-TestSite'!
SystemOrganization addCategory: #'WebStore-Components'!
SystemOrganization addCategory: #'WebStore-Admin'!
SystemOrganization addCategory: #'WebStore-Tests-Core'!
SystemOrganization addCategory: #'WebStore-Util'!
SystemOrganization addCategory: #'WebStore-Checkout'!
SystemOrganization addCategory: #'WebStore-Tests-UI'!
SystemOrganization addCategory: #'WebStore-Commands'!
SystemOrganization addCategory: #'WebStore-Tests-Commands'!
SystemOrganization addCategory: #'WebStore-TestResources'!

TestResource subclass: #WSMagmaResource
	instanceVariableNames: 'location session'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestResources'!

!WSMagmaResource methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 17:35'!
session
	session ifNil: [session := location newSession connectAs: 'testing'].
	^session! !

!WSMagmaResource methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:01'!
setUp
	location := MagmaLocalLocation path: 'testing.magma'.
	location isRepository 
		ifFalse: [MagmaRepositoryController create: location path root: Dictionary new]
		ifTrue: [[self session root: (Dictionary new)] on: Warning do: ["nothing"] ].! !

TestCase subclass: #WSAddressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Core'!

!WSAddressTest methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:11'!
testPopulateFrom
	| a1 a2 |
	a2 := WSAddress new.
	a1 := WSShippingAddress new.
	
	a2 address1: 'a'.
	a2 address2: 'b'.
	a2 locality: 'c'.
	a2 state: 'd'.
	a2 postcode: 'e'.
	a2 country: 'f'.
	
	a1 populateFrom: a2.
	self assert: a2 address1 equals: a1 address1.	
	self assert: a2 address2 equals: a1 address2.
	self assert: a2 locality equals: a1 locality.	
	self assert: a2 postcode equals: a1 postcode.
	self assert: a2 state equals: a1 state.
	self assert: a2 country equals: a1 country.
	self deny: a2 == a1.		! !

TestCase subclass: #WSCartTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Core'!

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:45'!
testAdd
	|c p|
	c := WSCart new.
	p := WSProduct new.
	p stock: 1.
	c add: p.
	
	self assert: c items includes: p.! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:54'!
testNewInstance
	|c|
	c := WSCart new.
	self assert: c empty.! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:55'!
testNotEmpty
	|c|
	c := WSCart new.
	c add: WSProduct new.
	self deny: c empty.! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:46'!
testRemove
	|c p|
	c := WSCart new.
	p := WSProduct new.
	p stock: 1.
	c add: p.
	c remove: p.
	
	self deny: (c items includes: p).! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:45'!
testTotalInDollars
	|c p1 p2|
	c := WSCart new.
	p1 := WSProduct new.
	p2 := WSProduct new.
	p1 stock: 1; price: 12345.
	p2 stock: 1; price: 54321.
	c add: p1.
	c add: p2.
	
	self assert: 666.66 equals: c totalInDollars.! !

TestCase subclass: #WSCommandTestCase
	instanceVariableNames: 'session store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Commands'!

WSCommandTestCase subclass: #WSApplyFormCommandTest
	instanceVariableNames: 'product form nameField priceField stockField descriptionField'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Commands'!

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 15:33'!
setUp
	super setUp.
	product := store products first.
	form := WSForm new.
	nameField := WSTestingField new on: #name of: product;
				 beRequired;
				 yourself.
	priceField := WSTestingField new on: #price of: product;
				 beRequired;
				 yourself.
	stockField := WSTestingField new on: #stock of: product;
				 beRequired;
				 yourself.
	descriptionField := WSTestingField new on: #description of: product;
				 yourself.
				
	form 
		add: nameField;
		add: priceField;
		add: stockField;
		add: descriptionField.! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 15:32'!
testUpdateDescription
	self updateForm.
	self runCommand: [WSApplyFormCommand form: form].
	session abort.
	self assert: 'testing' equals: product description! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:18'!
testUpdateName
	self updateForm.
	self runCommand: [WSApplyFormCommand form: form].
	session abort.
	self assert: 'newName' equals: product name! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:31'!
testUpdatePrice
	self updateForm.
	self runCommand: [WSApplyFormCommand form: form].
	session abort.
	self assert: 666 equals: product price! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:19'!
testUpdateStock
	self updateForm.
	self runCommand: [WSApplyFormCommand form: form].
	session abort.
	self assert: 10 equals: product stock! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:31'!
updateForm
	nameField value: 'newName'.
	priceField value: 666.
	stockField value: 10.
	descriptionField value: 'testing'! !

WSCommandTestCase subclass: #WSCancelOrderCommandTest
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Commands'!

!WSCancelOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:38'!
setUp
	super setUp.
	order := store orders first.! !

!WSCancelOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:39'!
testCancelOrder
	self runCommand: [WSCancelOrderCommand order: order].
	self assert: #cancelled equals: order status
! !

!WSCommandTestCase class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 23:08'!
resources
	^Array with: WSMagmaResource! !

!WSCommandTestCase methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:04'!
runCommand: aBlock 
	"aBlock should return a new Command"
	WACurrentSession 
		use: (WSTestSession new
				magmaSession: session;
				yourself)
		during: [ aBlock value run ]! !

!WSCommandTestCase methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:10'!
setUp
	super setUp.
	session := WSMagmaResource current session.
	store := WSTestingStore store.
	session commit: 
		[ session root 
			at: self class name
			put: store ].
! !

WSCommandTestCase subclass: #WSPlaceOrderCommandTest
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Commands'!

!WSPlaceOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:33'!
setUp
	super setUp.
	order := WSOrder new.
	order items: WSCart new.
! !

!WSPlaceOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:42'!
testFailedOrder
	| p |
	p := store products second.
	order items add: p.
			
	self should: [self runCommand: [WSPlaceOrderCommand store: store order: order]] raise: WSOutOfStockError.
! !

!WSPlaceOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:42'!
testFailedOrderRevertsStockLevels
	| p p2 |
	p := store products first.
	p2 := store products second.
	order items add: p.
	order items add: p2.
			
	[self runCommand: [WSPlaceOrderCommand store: store order: order]] on: WSOutOfStockError do: ["nothing"].
	self assert: ((p stock = 2) and: [p2 stock = 0]) description: 'Stock levels not restored'! !

!WSPlaceOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:36'!
testPlaceOrder
	order items add: store products first.
		
	self runCommand: [WSPlaceOrderCommand store: store order: order].
	self assert: #pending equals: order status
! !

WSCommandTestCase subclass: #WSShipOrderCommandTest
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Commands'!

!WSShipOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:39'!
setUp
	super setUp.
	order := store orders first.! !

!WSShipOrderCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:48'!
testShipOrder
	self runCommand: [WSShipOrderCommand order: order].
	self assert: #shipped equals: order status! !

WSCommandTestCase subclass: #WSTestProductCommands
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Commands'!

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 1/26/2009 13:39'!
testAddImage
	| p i |
	p := store products first.
	i := WSDummyImage baseName: 'newimage'.
	self runCommand:
		[ WSAddImageCommand 
			product: p
			image: i ].
	session abort.
	self assert: (p images includes: i)! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 1/26/2009 00:16'!
testDeleteImage
	| p i |
	p := store products first.
	i := p images first.
	self runCommand: 
		[ WSDeleteImageCommand 
			product: p
			image: i ].
	session abort.
	self deny: (p images includes: i)! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 1/26/2009 13:39'!
testSetPreview
	| p i |
	p := store products first.
	i := p images second.
	self runCommand: 
		[ WSSetPreviewCommand 
			product: p
			image: i].
	session abort.
	self assert: i equals: p preview.! !

TestCase subclass: #WSImageTest
	instanceVariableNames: 'image'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Core'!

!WSImageTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 15:04'!
setUp
	image := WSImage new! !

!WSImageTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 17:59'!
testNamePattern
	self assert: (image fullsize matchesRegex: '^[0-9a-f\-]+-full.jpg')! !

TestCase subclass: #WSOrderTest
	instanceVariableNames: 'p order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Core'!

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:02'!
setUp
	super setUp.
	p := WSProduct new stock: 5; yourself.
	order := WSOrder new 
		items: (WSCart new add: p;yourself); 
		yourself.
! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:09'!
testCancelledDate
	| time |
	order placeOrder: 123.
	time := DateAndTime now.
	order cancel.
	self assert: (order cancelledDate between: time and: time + 2 seconds)! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:04'!
testCancelledOrderStatus
	order placeOrder: 123.
	order cancel.
	self assert: #cancelled equals: order status! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 09:06'!
testCancelledUnplacedOrderDoesntAffectStockLevels
	order cancel.
	self assert: 5 equals: p stock! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:15'!
testCantShipCancelledOrder
	order placeOrder: 123.
	order cancel.
	self should: [order ship] raise: Error description: 'shouldn''t be able to ship a cancelled order'.
! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:15'!
testCantShipNewOrder
	self should: [order ship] raise: Error description: 'shouldn''t be able to ship a new order'.
! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:04'!
testInvalidOrder
	1 to: 5 do: [ :i | order items add: p].
	self should: [order placeOrder: 123] raise: WSOutOfStockError 	! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:06'!
testNewReference
	self assert: order reference isNil! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:05'!
testNewStatus
	self assert: #new equals: order status! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 20:44'!
testOrderDate
	| time |
	time := DateAndTime now.
	order placeOrder: 123.
	self assert: (order date between: time and: time + 2 seconds)! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:07'!
testOrderReference
	order placeOrder: 123.
	self assert: 123 equals: order reference.! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:07'!
testOrderStatus
	order placeOrder: 123.
	self assert: #pending equals: order status! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:08'!
testShipDate
	| time |
	order placeOrder: 123.
	time := DateAndTime now.
	order ship.
	self assert: (order shippedDate between: time and: time + 2 seconds)! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:10'!
testShippedStatus
	order placeOrder: 123.
	order ship.
	self assert: #shipped equals: order status! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:08'!
testStockReclamation
	order placeOrder: p.
	order cancel.
	
	self assert: 5 equals: p stock.! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:08'!
testStockReduction
	order placeOrder: 123.
	self assert: 4 equals: p stock! !

TestCase subclass: #WSPersistenceTest
	instanceVariableNames: 'magmaSession'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Core'!

!WSPersistenceTest class methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:24'!
resources
	^Array with: WSMagmaResource! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 17:31'!
setUp
	magmaSession := WSMagmaResource current session.! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:35'!
testAbort
	| s p |
	p := WSProduct new.
	s := WSStore new.
	magmaSession commit: [
		magmaSession root at: self class name put: s].
	
	magmaSession begin.
	s addProduct: p.
	magmaSession abort.
	self deny: (s products includes: p).! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:46'!
testAbortStockLevel
	| s p |
	p := WSProduct new stock: 5.
	s := WSStore new.
	s addProduct: p.
	magmaSession commit: [
		magmaSession root at: self class name put: s].
	
	magmaSession begin.
		p stock: 1.
	magmaSession abort.
	self assert: 5 equals: p stock.
	! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:37'!
testCommit
	| s p |
	p := WSProduct new.
	s := WSStore new.
	magmaSession commit: [
		magmaSession root at: self class name put: s].
	
	magmaSession begin.
	s addProduct: p.
	magmaSession commit.
	self assert: (s products includes: p).! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:43'!
testCommitStockLevel
	| s p |
	p := WSProduct new stock: 5.
	s := WSStore new.
	s addProduct: p.
	magmaSession commit: [
		magmaSession root at: self class name put: s].
	
	magmaSession begin.
		p stock: 1.
	magmaSession commit.
	self assert: 1 equals: p stock.
	! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:31'!
testPersist
	| s |
	s := WSStore new.
	magmaSession commit: [
		magmaSession root at: self class name put: s].
	
	self assert: s equals: (magmaSession root at: self class name)! !

TestCase subclass: #WSProductTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Core'!

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:04'!
testAddFirstImageSetsPreview
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	self assert: i equals: p preview! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:03'!
testAddImage
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	self assert: p images includes: i.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:53'!
testNewProduct
	|p|
	p := WSProduct new.
	self assert: p images isEmpty.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:25'!
testPreviewMustBeInImages
	| p i1 i2 |
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	
	p addImage: i1.
	self should: [p preview: i2] raise: Exception whoseDescriptionIncludes: 'must be one of the product''s images'  description: 'Didn''t raise expected Exception'! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:03'!
testPriceInDollars
	self assert: 30.45 equals: (WSProduct new price: 3045;priceInDollars)! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:05'!
testRemoveImage
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	p removeImage: i.
	
	self assert: (p images includes: i) not.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:18'!
testRemoveImageResetsPreview
	|p i1 i2|
	
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	p addImage: i1.
	p addImage: i2.
	p preview: i2.
	p removeImage: i2.
	
	self assert: i1 equals: p preview! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:07'!
testRemoveLastImageUnsetsPreview
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	p removeImage: i.
	
	self assert: p preview isNil..! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:18'!
testSetPreview
	|p i1 i2|
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	p addImage: i1.
	p addImage: i2.
	p preview: i2.
	
	self assert: i2 equals: p preview! !

TestCase subclass: #WSStoreTest
	instanceVariableNames: 'store p order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Core'!

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:15'!
setUp
	super setUp.
	store := WSStore new.
	p := WSProduct new stock: 5; yourself.
	order := WSOrder new 
		items: (WSCart new add: p;yourself); 
		yourself.! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:16'!
testAddProduct
	store addProduct: p.
	self assert: (store products includes: p).
	! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:16'!
testDeleteProduct
	store addProduct: p.
	store deleteProduct: p.
	self assert: (store products includes: p) not	! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:06'!
testOrderReference
	store placeOrder: order.
	self assert: order reference notNil.! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:02'!
testPlaceOrder
	store placeOrder: order.
	self assert: store orders includes: order.! !

WAFileLibrary subclass: #TestSiteFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestSite'!

!TestSiteFiles methodsFor: 'uploaded' stamp: 'srh 1/1/2009 22:15'!
webstoreCss
	^ '
#banner {
	position: absolute;
	top: 0;
	height: 2em;
	left: 0;
	right: 0;
	margin:0;
	font-size: 2em;
	border-bottom: solid 1px grey;
}
#nav {
	position: absolute;
	left: 0;
	top: 4em;
	width: 8em;
}

#content {
	position: absolute;
	top: 4em;
	left: 8em;
	margin-top: 0;
	border-left: solid 1px grey;
	padding-left: 1em;
	padding-top: 5px;
}

.product-preview {
	float: left;
	border: dashed 1px grey;
	margin: 3px;
	height: 8.5em;
	width: 12em;
	padding: 3px;
}

.product-preview img {
	float: left;
	margin-right: 0.5em;
	margin-bottom: 0.5em;
}
.product-preview h3 {
	margin-top: 0;
	margin-bottom: 0;
	font-size: 1em;
	clear: both;
}
.product-preview p {
	margin-top: 0;
	margin-bottom: 0;
}

.product-preview a {
	text-decoration: none;
}

.product-preview img {
	border: none;
}

.product-details {
	margin-bottom: 2em;
}

.product-details h2 {
	margin-top: 0;
}

.product-details .image-viewer {
	float: left;
	margin-right: 1em;
	margin-bottom: 0.5em;
}

.image-viewer {
	border: solid grey 1px;
	padding: 0;
	text-align: center;
}

.image-viewer img {
	border:none;
	padding: none;
}

.image-viewer ul {
	margin: 0;
	padding: 0;
	list-style: none;
	border-top: solid grey 1px;
	background-color: #eeeeee;
}

.image-viewer li {
	display: inline;
	margin: 0;
	padding: 0;
}

#lightbox {
	background-color: white;
	border: solid #404040 1px;
}

#lightbox h1 {
	background-color: #eeeeee;
	margin-top: 0;
	padding: 2x;
	text-align: center;
	font-size: 1.2em;
}

#lightbox .nav-buttons {
	background-color: #eeeeee;
	padding: 0.2em;
	text-align: right;
}

ul.wizard-tabs {
	list-style: none;
	margin: 0;
	padding: 0;
}

.wizard-tabs li {
	display: inline;
	margin-left: 0.5em;
	margin-right: 0.5em;
}

.wizard-tabs li.disabled {
	color: grey;
}

.cart-view {
	margin: 0.5em;
}

#confirm-order {
	padding-left: 0.5em;
	padding-right: 0.5em;
}

#confirm-order h2 {
	margin-top: 0;
	margin-bottom: 0;
	font-size: 1.2em;
}

#confirm-order div {
	margin: 0;
}
#confirm-order p {
	margin-top: 0;
}

#confirm-order dl {
	margin-top: 0.5em;
	padding: 0;
}

#confirm-order dt {
	font-weight: bold;
}

#confirm-order dd {
	margin-left: 8em;
	margin-top: -1em;
}

label {
	width: 10em;
	display: inline-block;
	text-align: right;
	margin-right: 0.5em;
}
'! !

WAFileLibrary subclass: #WSImageLibrary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSImageLibrary commentStamp: '<historical>' prior: 0!
This class adds the ability to serve content from files external to the image.

The files go in to a subdirectory from the running directory called 'files'
The URL to access the files is: http://localhost:7777/seaside/files/external/myfile.png

Seaside protects against malicious users attempting to use '..' to access above the 'files' directory.!

!WSImageLibrary class methodsFor: 'testing' stamp: 'srh 12/31/2008 08:05'!
handlesFolder: aSymbol 
	^ aSymbol = #external! !

!WSImageLibrary class methodsFor: 'testing' stamp: 'srh 12/31/2008 08:40'!
path
	^'files/external/'! !

!WSImageLibrary methodsFor: 'accessing' stamp: 'srh 12/31/2008 08:31'!
documentAt: aFilename ifAbsent: aBlock 
	| fn files mimeType fileStream |
	files := FileDirectory default directoryNamed: 'files'.
	files exists
		ifFalse: [^ aBlock value].
	fn := files fullNameFor: aFilename.
	^ (files fileOrDirectoryExists: fn)
		ifTrue: [mimeType := self mimetypeForFile: aFilename.
			fileStream := (files readOnlyFileNamed: fn) binary.
			(WAStreamResponse on: fileStream)
				contentType: (mimeType
						ifNil: ['application/octet-stream']);
				 headerAt: 'Expires' put: 'Thu, 01 Jan 2095 12:00:00 GMT';
				 yourself]
		ifFalse: [aBlock value]! !

!WSImageLibrary methodsFor: 'accessing' stamp: 'srh 12/31/2008 08:06'!
urlOf: aSymbol using: aHandler 
	^ aHandler baseUrl addToPath: 'external';
		
		addToPath: (self asFilename: aSymbol);
		 yourself! !

SCComponentTestCase subclass: #WSStoreAdminTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:53'!
configureApplicationForComponent: aComponentClass
	super configureApplicationForComponent: aComponentClass.
	app preferenceAt: #sessionClass put: WSTestSession.! !

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 11:47'!
setUp
	self newApplicationWithRootClass: WSStoreAdmin.
	self establishSession.
! !

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 20:30'!
testManageOrders
	self followAnchor: (self lastResponse anchorWithLabel: 'Manage Orders').
	self assert: (self lastResponse entitiesNamed: 'label') first contentString 
				= 'Show: '! !

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 11:50'!
testManageProducts
	self followAnchor: (self lastResponse anchorWithLabel: 'Manage Products').
	self assert: (self lastResponse entitiesNamed: 'a') first contentString 
				= 'Add Product'! !

SCComponentTestCase subclass: #WSWebTest
	instanceVariableNames: 'store sessionBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

WSWebTest subclass: #WSCartViewTest
	instanceVariableNames: 'cart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

WSCartViewTest subclass: #WSCartViewDialogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSCartViewDialogTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:43'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSCartViewDialog
		initializeWith: [ :c | c cart: aCart ].
	self establishSession! !

!WSCartViewDialogTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:14'!
testBack
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Back').
	self assert: self componentAnswered.! !

!WSCartViewDialogTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:35'!
testCheckout
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Checkout').
	self assert: 'wizard-tabs' equals: self lastResponse bodyElement entities first cssClass ! !

!WSCartViewDialogTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:05'!
testTitle
	self initialRequest.
	self assert: 'Current Order' equals: (self lastResponse entitiesNamed: 'h1') first contentString.! !

WSCartViewTest subclass: #WSCartViewPageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSCartViewPageTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:45'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSCartViewPage 
		initializeWith: [ :c | c model: (WSOrder new items: aCart; yourself) ].
	self establishSession! !

!WSCartViewPageTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:37'!
testEnabled
	self initialRequest.
	self assert: self component enabled! !

!WSCartViewPageTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:37'!
testValid
	self initialRequest.
	self assert: self component valid! !

!WSCartViewTest class methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:47'!
shouldInheritSelectors
	^true! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:01'!
initialRequest
	self initialRequestWith: cart! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 13:55'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSCartView
		initializeWith: [ :c | c cart: aCart ].
	self establishSession! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:06'!
itemCount
	^((self lastResponse entityWithId: 'cart-items') entitiesNamed: 'tr') size.! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:10'!
itemRow: itemNo
	^(((self lastResponse entityWithId: 'cart-items') entitiesNamed: 'tr') at: itemNo) entitiesNamed: 'td'! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:15'!
nameOf: itemNo
	^((self itemRow: itemNo) at: 2) contentString.! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:16'!
previewFor: itemNo
	^((self itemRow: itemNo) first) entities first! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:15'!
priceOf: itemNo
	^((self itemRow: itemNo) at: 3) contentString.! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:53'!
removeAnchorFor: itemNo
	^((self itemRow: itemNo) at: 4) anchors first.! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:39'!
setUp
	super setUp.
	cart := WSCart new.
	store products second stock: 1.
	cart add: store products first.
	cart add: store products second.
! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:01'!
testItems
	self initialRequest.
	self 
		assert: 2
		equals: self itemCount! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:40'!
testNames
	self initialRequest.
	self 
		assert: (store products first) name
		equals: (self nameOf: 1).
	self 
		assert: (store products second) name
		equals: (self nameOf: 2)
		! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:41'!
testPreviews
	self initialRequest.
	self 
		assert: WSImageLibrary path, store products first preview thumbnail
		equals: ((self previewFor: 1) attributeAt: 'src').
	self 
		assert: WSImageLibrary path, store products second preview thumbnail
		equals: ((self previewFor: 2) attributeAt: 'src').
! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:41'!
testPrices
	self initialRequest.
	self 
		assert: '$', store products first priceInDollars printString
		equals: (self priceOf: 1).
	self 
		assert: '$', store products second priceInDollars printString
		equals: (self priceOf: 2)
		! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:04'!
testRemoveItem
	self initialRequest.
	self followAnchor: (self removeAnchorFor: 1).
	self assert: 1 equals: self itemCount! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:41'!
testRemoveItemUpdatesTotal
	self initialRequest.
	self followAnchor: (self removeAnchorFor: 1).
	self assert: '$', store products second priceInDollars printString equals: self total! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:04'!
testTotal
	self initialRequest.
	self 
		assert: '$' , cart totalInDollars printString
		equals: self total! !

!WSCartViewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:05'!
total
	^(self lastResponse entityWithId: 'cart-total') contentString! !

WSWebTest subclass: #WSCartWidgetTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSCartWidgetTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:33'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSCartWidget
		initializeWith: [ :w | w parent: w].
	sessionBlock := [ :s | s cart: aCart].
	self establishSession! !

!WSCartWidgetTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:42'!
testDetails
	self initialRequestWith: (WSCart new add: store products first; yourself).
	self assert: 'Items: 1 Total: $', store products first priceInDollars printString equals: (self lastResponse entitiesNamed: 'p') first contentString! !

!WSCartWidgetTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:17'!
testEmpty
	self initialRequestWith: WSCart new.
	self assert: 0 equals: (self lastResponse entitiesWithClass: 'cart-widget') first entities size.! !

!WSCartWidgetTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:42'!
testNotEmpty
	self initialRequestWith: (WSCart new add: store products first; yourself).
	self assert: 'Your Order' equals: (self lastResponse entitiesNamed: 'h3') first contentString.! !

!WSCartWidgetTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:42'!
testReview
	self initialRequestWith: (WSCart new add: store products first; yourself).
	self followAnchor: (self lastResponse anchorWithLabel: 'Review').
	
	self assert: 'Current Order' equals: (self lastResponse entitiesNamed: 'h1') first contentString.! !

WSWebTest subclass: #WSCheckoutProcessTest
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:40'!
initialize
	super initialize.
	sessionBlock := [ :s | s store: store]! !

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:22'!
placeOrder: anOrder
	self newApplicationWithRootClass: WSCheckoutProcess
		initializeWith: [ :c | c wizard:(WSTestOrderWizard new order: anOrder;yourself) ].
	self establishSession! !

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:43'!
setUp
	super setUp.
	order := WSOrder new
		customer: (WSCustomer new
			name: 'Stuart Herring';
			address: (WSAddress new
				address1: 'Over here';
				locality: 'Testville';
				postcode: '1234';
				state: 'ACT';
				country: 'Australia');
			phone: '123459567';
			email: 'testing@example.com');
		address: (WSShippingAddress new
				name: 'Stuart Herring';
				address1: 'Over here';
				locality: 'Testville';
				postcode: '1234';
				state: 'ACT';
				country: 'Australia').! !

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 11:58'!
testFailedOrder
	order items: (WSCart new add: store products second; yourself).
	self placeOrder: order.
	self assert: 'Order Failed' equals: (self lastResponse entitiesNamed: 'h1') first contentString.! !

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 11:58'!
testFailedOrderReturnsToReviewOrderTab
	order items: (WSCart new add: store products second; yourself).
	self placeOrder: order.
	self followAnchor: (self lastResponse anchorWithLabel: 'Back').
	self assert: 1 equals: self component wizard page! !

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 11:58'!
testOrderReference
	order items: (WSCart new add: store products first;yourself).
	self placeOrder: order.
	self assert: 
		((self lastResponse entitiesNamed: 'p') first contentString endsWith: 'is: ', order reference).! !

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 11:58'!
testPlaceOrder
	order items: (WSCart new add: store products first;yourself).
	self placeOrder: order.
	self assert: 'Order Complete' equals: (self lastResponse entitiesNamed: 'h1') first contentString.! !

!WSCheckoutProcessTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 11:58'!
testPlaceOrderAndClose
	order items: (WSCart new add: store products first;yourself).
	self placeOrder: order.
	self followAnchor: (self lastResponse anchorWithLabel: 'Close').
	self assert: self componentAnswered.! !

WSWebTest subclass: #WSImageManagerTest
	instanceVariableNames: 'p'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:07'!
initialRequest
	self newApplicationWithRootClass: WSImageManager
		createWith: [ WSImageManager for: p ].
	self establishSession! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:04'!
setUp
	super setUp.
	p := store products first.! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:34'!
testAdd
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Add Image').
	self assert: SCFileHtmlInput  equals: (self lastResponse entitiesNamed: 'input') first class! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:19'!
testDelete
	| i|
	i := p images first.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') first.
	self deny: (p images includes: i)! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:08'!
testDone
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Done').
	self assert: self componentAnswered.! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:33'!
testEdit
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Edit') first.
	self assert: SCFileHtmlInput  equals: (self lastResponse entitiesNamed: 'input') first class! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:17'!
testSetAsPreview
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Set as Preview') second.
	self assert: p images second equals: p preview! !

WSWebTest subclass: #WSOrderManagerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:29'!
formatDate: aDate
	^aDate asDate printFormat: #(3 2 1 - 1 1 2).! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:10'!
initialRequest
	self newApplicationWithRootClass: WSOrderManager
		createWith: [ WSOrderManager store: store ].
	self establishSession! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:49'!
rows
	| table |
	table := (self lastResponse entitiesNamed: 'table') first.
	^(table entitiesNamed: 'tr') allButFirst collect: [ :tr | tr entitiesNamed: 'td' ]! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:49'!
setUp
	super setUp.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:06'!
testCancel
	self initialRequest.
	self followAnchor: (self  lastResponse anchorWithLabel: 'Cancel').
	self confirmYes.
	self assert: ((self rows first at: 6) contentString beginsWith: 'Cancelled')! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:49'!
testDone
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Done').
	self assert: self componentAnswered.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:20'!
testFilter
	| form | 
	self initialRequest.
	form := 	self lastResponse forms first.
	(form entitiesNamed: #input) first selectOptionWithText: 'Cancelled'.
	self submitForm: form.
	self assert: 1 equals: self rows size! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:10'!
testFilterSelectsCorrectRecords
	| form | 
	self initialRequest.
	form := 	self lastResponse forms first.
	(form entitiesNamed: #input) first selectOptionWithText: 'Cancelled'.
	self submitForm: form.
	self assert: ((self rows first at: 6) contentString beginsWith: 'Cancelled')! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 14:04'!
testListSize
	self initialRequest.
	self assert: store orders size  equals: self rows size.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:06'!
testShip
	self initialRequest.
	self followAnchor: (self  lastResponse anchorWithLabel: 'Ship').
	self confirmYes.
	self assert: ((self rows first at: 6) contentString beginsWith: 'Shipped')! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:07'!
testShowCancelledDate
	| o |
	o := store orders second.
	self initialRequest.
	self 
		assert: 'Cancelled (', (self formatDate: o cancelledDate), ')' 
		equals: ((self rows second) at: 6) contentString.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:24'!
testShowItems
	self initialRequest.
	self assert: store orders first items count printString equals: ((self rows first) at: 3) contentString.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:19'!
testShowName
	self initialRequest.
	self assert: store orders first customer name equals: (self rows first) second contentString.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:51'!
testShowReference
	self initialRequest.
	self assert: store orders first reference equals: (self rows first) first contentString.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:07'!
testShowShippedDate
	| o |
	o := store orders third.
	self initialRequest.
	self 
		assert: 'Shipped (', (self formatDate: o shippedDate), ')' 
		equals: ((self rows third) at: 6) contentString.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:08'!
testShowStatus
	self initialRequest.
	self assert:  (((self rows first) at: 6) contentString beginsWith: (store orders first status asCapitalizedPhrase))! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 14:12'!
testShowTotal
	self initialRequest.
	self assert: '$', store orders first items totalInDollars printString equals: ((self rows first) at: 4) contentString.! !

WSWebTest subclass: #WSProductManagerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:09'!
initialRequest
	self newApplicationWithRootClass: WSProductManager
		createWith: [ WSProductManager store: store ].
	self establishSession! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:31'!
rows
	| table |
	table := (self lastResponse entitiesNamed: 'table') first.
	^(table entitiesNamed: 'tr') allButFirst collect: [ :tr | tr entitiesNamed: 'td' ]! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:12'!
setUp
	super setUp.! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:50'!
testAdd
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Add Product').
	self assert: 'Name:'  equals: (self lastResponse entitiesNamed: 'label') first contentString! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:40'!
testDelete
	| name |
	name :=  store products second name.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self assert: 'Really delete ', name, '?' equals: (self lastResponse entitiesNamed: 'h3') first contentString.! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:48'!
testDeleteCancel
	| size |
	size :=  store products size.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self confirmNo.
	self assert: size equals: self rows size! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:49'!
testDeleteConfirm
	| size |
	size :=  store products size.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self confirmYes.
	self assert: (size - 1) equals: self rows size! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:49'!
testDeleteRemovesCorrectItem
	| name |
	name :=  store products second name.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self confirmYes.
	self deny: (self rows anySatisfy: [:r | name = r second contentString ])! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:08'!
testDone
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Done').
	self assert: self componentAnswered.! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:50'!
testEdit
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Edit') first.
	self assert: 'Name:'  equals: (self lastResponse entitiesNamed: 'label') first contentString.! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:29'!
testList
	self initialRequest.
	self assert: store products second name  equals: (self rows second) second contentString.! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:29'!
testListSize
	self initialRequest.
	self assert: store products size  equals: self rows size.! !

WSWebTest subclass: #WSProductPreviewTest
	instanceVariableNames: 'product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
initialRequest
	self 
		newApplicationWithRootClass: WSProductPreviewComponent
		initializeWith: [ :view | view product: product ].
	self establishSession! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
setUp
	super setUp.
	product := store products first! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
testAddToCart
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Add to Order').
	self 
		assert: self session cart items
		includes: product! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 13:44'!
testInStock
	self initialRequest.
	self 
		assert: 'Add to Order'
		equals: (self lastResponse entitiesNamed: 'p') second anchors first contentString! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
testName
	self initialRequest.
	self 
		assert: product name
		equals: (self lastResponse entitiesNamed: 'h3') first anchors first contentString! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
testOutOfStock
	product stock: 0.
	self initialRequest.
	self 
		assert: 'Out of stock'
		equals: (self lastResponse bodyElement entitiesNamed: 'p') second contentString! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
testPreviewImage
	self initialRequest.
	self 
		assert: WSImageLibrary path , product preview thumbnail
		equals: ((self lastResponse bodyElement entitiesNamed: 'img') first attributeAt: 'src')! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
testPrice
	self initialRequest.
	self 
		assert: '$' , product priceInDollars printString
		equals: (self lastResponse entitiesNamed: 'p') first contentString! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:44'!
testViewDetails
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: product name).
	self 
		assert: 'product-details'
		equals: (self lastResponse entitiesNamed: 'div') first cssClass! !

!WSProductPreviewTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 13:44'!
testViewDetailsFromImage
	self initialRequest.
	self followAnchor: (self lastResponse anchors detect: [ :a | a entities first tag = 'img' ]).
	self 
		assert: 'product-details'
		equals: (self lastResponse entitiesNamed: 'div') first cssClass! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 19:43'!
configureApplicationForComponent: aComponentClass
	super configureApplicationForComponent: aComponentClass.
	app preferenceAt: #sessionClass put: WSTestSession.! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:47'!
confirmNo
	| form |
	form := self lastResponse forms first.
	self submitForm: form pressingButton: (form buttons detect: [:b | b value = 'No']).
! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:47'!
confirmYes
	| form |
	form := self lastResponse forms first.
	self submitForm: form pressingButton: (form buttons detect: [:b | b value = 'Yes']).
! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:39'!
sessionCreated: aSession
	sessionBlock ifNotNil: [ sessionBlock value: aSession]! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:37'!
setUp
	super setUp.
	store := WSTestingStore store.
! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 16:06'!
store
	^store! !

WAComponent subclass: #TestSite
	instanceVariableNames: 'store products cartWidget'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestSite'!

!TestSite class methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 12:53'!
canBeRoot
	^true! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:30'!
children
	^Array with: products with: cartWidget.! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 17:26'!
initialize
	| |
	super initialize.
	products := WSProductList products: self store products..
	cartWidget := WSCartWidget parent: self.! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 10:03'!
renderContentOn: html
	html heading id: 'banner'; with: 'Emma''s Store'.
	html div id: 'nav';with: [
		html unorderedList with: [
			html listItem: [ html anchor callback: []; with: 'Home'].
			html listItem: [ html anchor callback: []; with: 'A link'].
		].
		html render: cartWidget.
	].
	html div id: 'content';with:products! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 17:26'!
store
	^self session store! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 12:58'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot	stylesheet 
		url: TestSiteFiles  / #webstoreCss! !

WAComponent subclass: #WSCartView
	instanceVariableNames: 'cart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSCartView class methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 13:57'!
cart: aCart
	^self basicNew
		cart: aCart;
		initialize;
		yourself! !

!WSCartView methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 13:57'!
cart
	^cart! !

!WSCartView methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 13:56'!
cart: aCart
	cart := aCart! !

!WSCartView methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:55'!
renderContentOn: html
	html div class: 'cart-view'; with: [
		html table: [
		html tableRow: [
			html tableHeading colSpan: 2; with: 'Item'.
			html tableHeading: 'Price'.
			html tableHeading].
		html tableBody id: 'cart-items'; with: [
		self cart items do: [ :p | html tableRow: [
			html tableData: [
				p preview ifNotNil: [ html image resourceUrl: WSImageLibrary path, p preview thumbnail]].
			html tableData: p name.
			html tableData: '$', p priceInDollars printString.
			html tableData: [ html anchor callback: [self cart remove: p]; with: 'Remove']]]
		].
		html tableRow: [
			html tableData.
			html tableData: 'Total: '.
			html tableHeading id: 'cart-total'; with: '$', self cart totalInDollars printString.
			html tableData.
		]
	]].
! !

WAComponent subclass: #WSCartViewDialog
	instanceVariableNames: 'cartView'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSCartViewDialog class methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:54'!
cart: aCart
	^self basicNew
		initialize;
		cart: aCart;
		yourself! !

!WSCartViewDialog methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:41'!
cart: aCart
	cartView := WSCartView cart: aCart! !

!WSCartViewDialog methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 10:59'!
children
	^Array with: cartView.! !

!WSCartViewDialog methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:41'!
initialize
	super initialize.
	cartView := WSCartView new! !

!WSCartViewDialog methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 19:15'!
renderContentOn: html
		html heading level:1; with: 'Current Order'.
		html render: cartView.
		html div class: 'nav-buttons'; with: [
		html anchor callback: [ self answer]; with: 'Back'.
		html text: ' '.
		html anchor callback: [ self answer: (self call: WSCheckoutProcess new) ]; with: 'Checkout'.
	]! !

WAComponent subclass: #WSCartWidget
	instanceVariableNames: 'parent inCart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSCartWidget class methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:33'!
parent: aComponent
	^self basicNew
		parent: aComponent;
		initialize;
		yourself.! !

!WSCartWidget methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:34'!
cart
	^self session cart.! !

!WSCartWidget methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 10:20'!
initialize
	super initialize.
	inCart := false.
	! !

!WSCartWidget methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:34'!
parent: aComponent
	parent := aComponent.! !

!WSCartWidget methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:34'!
renderContentOn: html
	html div class: 'cart-widget'; with: [	self cart empty ifFalse: [
		html heading level: 3; with: 'Your Order'.
		html paragraph: 'Items: ', self cart count printString, ' Total: $', self cart totalInDollars printString.
		html paragraph: [
			html anchor callback: [parent lightbox: (WSCartViewDialog cart: self cart)]; with: 'Review']]]! !

WAComponent subclass: #WSCheckoutWizard
	instanceVariableNames: 'page order pages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSCheckoutWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:46'!
children
	^ pages! !

!WSCheckoutWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 10:34'!
goToFirstPage
	page := pages first! !

!WSCheckoutWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 09:01'!
initialize
	super initialize.
	page := WSCustomerPage new.
	pages := OrderedCollection new
		add: WSCartViewPage new;
		add: page;
		add: WSShippingAddressPage new;
		add: WSConfirmOrderPage new;
		yourself.
	order := WSOrder new.
	order items: self session cart.
	pages do: [ :p | p model: order ].
	page onEnter.! !

!WSCheckoutWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 07:53'!
renderButtonsOn: html 
	html div class: 'nav-buttons'; with: 
		[ html cancelButton
			callback: [ self answer: nil ];
			value: 'Cancel'.
		html space.
		page = pages first ifFalse: 
			[ html cancelButton
				callback: [ page := pages before: page ];
				value: 'Previous' ].
		html space.
		page = pages last 
			ifFalse: 
				[ html submitButton
					callback: 
						[ (page save and: [ page valid ]) ifTrue: [ page := pages after: page. page onEnter ] ];
					value: 'Next' ]
			ifTrue: 
				[ html submitButton
					callback: [ (page save and: [ page valid ]) ifTrue: [ self answer: order ] ];
					value: 'Done' ] ]! !

!WSCheckoutWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:04'!
renderContentOn: html
	self renderNavOn: html.
	self renderTitleOn: html.
	html form: [
		html render: page.
		self renderButtonsOn: html
	].! !

!WSCheckoutWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:46'!
renderNavOn: html 
	html unorderedList
		class: 'wizard-tabs';
		with: 
			[ pages do: 
				[ :p | 
				html listItem
					class: (p enabled ifFalse: [ 'disabled' ]);
					with: 
						[ (p = page or: [ p enabled not ]) 
							ifTrue: [ html text: p title ]
							ifFalse: 
								[ html anchor
									callback: [ page := p ];
									with: p title ] ] ] ]! !

!WSCheckoutWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 12:57'!
renderTitleOn: html
	html heading: page title! !

WAComponent subclass: #WSField
	instanceVariableNames: 'value selector receiver tag label rules'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:50'!
image
	^WSImageField new.! !

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 10:28'!
integer
	^WSIntegerField new.! !

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:57'!
largeText
	^self basicNew
		tagType:  #textArea;
		initialize;
		yourself.! !

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:15'!
money
	^WSMoneyField new.! !

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:13'!
text
	^self basicNew
		tagType:  #textInput;
		initialize;
		yourself.! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:05'!
addRule: aBlock withDescription: desc.
	rules add: (WSRule rule: aBlock message: desc)! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:24'!
beRequired
	"Nil is allowed, because the only time it'll be nil is when the form is first rendered"
	self addRule: [ :v| v isNil or: [v notEmpty]] withDescription: self label, ' is a required field'.! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 17:25'!
initialize
	super initialize.
	rules := OrderedCollection new.! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:24'!
label
	^label ifNil:[label := selector asCapitalizedPhrase]! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 17:05'!
label: aString
	label := aString! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:06'!
messages
	^rules select: [ :r | (r testRule: value) not] thenCollect: [ :r | r message ] ! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:06'!
on: aSelector of: aReceiver 
	selector := aSelector.
	receiver := aReceiver.
	self readValue! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:06'!
readValue
	value := receiver perform: selector! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:24'!
renderContentOn: html
	html div class: (self valid ifFalse: ['error']); with: [
		| id |
		id := html nextId.
		html label for: id; with: self label, ':'.
		(html perform: tag) 
			id: id;
			callback: [ :v| value := v];
			value: value
		]! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:08'!
save
	receiver perform: selector asMutator with: value! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 17:01'!
tagType: symbol
	tag := symbol! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:06'!
valid
	^rules allSatisfy: [ :r | r  testRule: value ]! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:55'!
value
	^value! !

WSField subclass: #WSImageField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSImageField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:55'!
new
	^self basicNew
		tagType: #fileUpload;
		initialize;
		yourself.! !

!WSImageField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:06'!
readValue
	"Can't do anything sensible here"
	! !

WSField subclass: #WSIntegerField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSIntegerField class methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 10:24'!
new
	^self basicNew
		tagType: #textInput;
		initialize;
		yourself.! !

!WSIntegerField methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 10:30'!
initialize
	super initialize.
	self addRule: [ :v | v asInteger notNil ] withDescription: 'Must be a number'.! !

!WSIntegerField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:06'!
readValue
	value := receiver perform: selector.
	value ifNotNil: [ value := value printString ]! !

!WSIntegerField methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 10:25'!
save
	receiver perform: selector asMutator with: value asInteger! !

WSField subclass: #WSMoneyField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSMoneyField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:18'!
new
	^self basicNew
		tagType: #textInput;
		initialize;
		yourself.! !

!WSMoneyField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:06'!
readValue
	value := receiver perform: selector.
	value ifNotNil: [ value := (value / 100) asFloat printString ]! !

!WSMoneyField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:18'!
save
	receiver perform: selector asMutator with: ((value asNumber) * 100) asInteger! !

WSField subclass: #WSTestingField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-Commands'!

!WSTestingField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:07'!
value: newValue
	value := newValue.! !

WAComponent subclass: #WSForm
	instanceVariableNames: 'fields rules'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 15:36'!
add: aField
	fields add: aField! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 19:08'!
addRule: aBlock withDescription: aMessage
	rules add: (WSRule rule: aBlock message: aMessage).! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 15:17'!
children
	^fields! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 19:09'!
initialize
	super initialize.
	fields := OrderedCollection new.
	rules := OrderedCollection new.! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:22'!
messages
	^rules select: [ :r | (r testRule: self) not] thenCollect: [ :r | r message ] .! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 15:20'!
renderContentOn: html
	self renderMessagesOn: html.
	fields do: [:f | html render: f].
! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:50'!
renderMessagesOn: html
	self valid ifFalse: [
		| messages |
		messages := OrderedCollection new.
		messages addAll: self messages.
		fields collect: [:f | messages addAll: f messages ].
		html unorderedList: [ 
			messages do: [ :m | html listItem: m]]]! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 15:33'!
save
	fields do: [:f | f save]! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:06'!
updateFromModel
	fields do: [ :f | f readValue ]! !

!WSForm methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:50'!
valid
	^(fields allSatisfy: [:f | f valid]) and: [rules allSatisfy: [:r | r testRule: self]].! !

WAComponent subclass: #WSImageEditor
	instanceVariableNames: 'image imageField'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSImageEditor class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:54'!
image: anImage
	^self basicNew
		initializeWithImage: anImage;
		yourself.! !

!WSImageEditor class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:54'!
new
	^self image: nil! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:57'!
children
	^Array with: imageField! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 15:07'!
imageFile: aWAFile
	aWAFile ifNotNil: [
		image := WSImage fromStream: (ReadStream on: aWAFile contents asByteArray)]! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:56'!
initializeWithImage: anImage
	self initialize.
	image := anImage.
	imageField := WSField image
		label: 'Select an Image';
		on: #imageFile of: self;
		yourself.
! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:35'!
renderContentOn: html
	html form multipart; with: [
		html render: imageField.
		html div: [
			html cancelButton callback: [self answer: nil]; value: 'Cancel'.
			html submitButton callback: [self save]; value: 'Preview'.
			html submitButton callback: [self saveAndAnswer]; value: 'Done'	
		]
	].
	image ifNotNil: [
		html div: [
			html image resourceUrl: WSImageLibrary path, image thumbnail.
			html image resourceUrl: WSImageLibrary path, image medium.
		]		
	]

! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 15:35'!
save
	imageField valid ifTrue: [(WSApplyFormCommand form: imageField) run].	! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 23:29'!
saveAndAnswer
	self save.
	self answer: image! !

WAComponent subclass: #WSImageManager
	instanceVariableNames: 'product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSImageManager class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:55'!
for: aProduct
	^self basicNew
		initializeWithProduct: aProduct;
		yourself.! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 21:39'!
addImage: anImage
	anImage ifNotNil: [product addImage: anImage].! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:33'!
delete: anImage
	(WSDeleteImageCommand product: product image: anImage) run.
! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:08'!
edit: anImage
	self call: (WSImageEditor image: anImage).
! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:56'!
initializeWithProduct: aProduct.
	self initialize.
	product := aProduct.! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 21:41'!
renderContentOn: html
	html anchor callback: [self addImage: (self call: WSImageEditor new)]; with: 'Add Image'.
	html text: ' '.
	html anchor callback: [self answer]; with: 'Done'.
	self renderImageListOn: html.! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:36'!
renderImageListOn: html
	product images do: [:i |
		html div: [
			html div 
				class: (product preview = i ifTrue: ['preview']); 
				with: [html image resourceUrl: WSImageLibrary path, i thumbnail].
			html div: [
				html anchor callback:  [product preview: i]; with: 'Set as Preview'.
				html text: ' '.
				html anchor callback: [self edit: i]; with: 'Edit'].
				html text: ' '.
				html anchor callback: [self delete: i]; with: 'Delete']]! !

WAComponent subclass: #WSOrderErrorPage
	instanceVariableNames: 'error'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSOrderErrorPage class methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 10:30'!
error: anException
	^self basicNew
		error: anException;
		initialize;
		yourself.! !

!WSOrderErrorPage methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 10:30'!
error: anException
	error := anException! !

!WSOrderErrorPage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:52'!
renderContentOn: html
	html heading: 'Order Failed'.
	html paragraph: 'An error ocurred while processing your order: ', error printString.
	html div class: 'nav-buttons'; with: [ html anchor callback: [self answer]; with: 'Back']! !

WAComponent subclass: #WSOrderManager
	instanceVariableNames: 'filter store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSOrderManager class methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:47'!
store: aStore
	^self basicNew
		initializeWithStore: aStore;
		yourself.! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:04'!
formatDate: aDate
	^aDate asDate printFormat: #(3 2 1 - 1 1 2) ! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/2/2009 17:56'!
initializeWithStore: aStore
	store := aStore.
	self initialize.! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:10'!
orders
	^filter isNil 
		ifTrue: [store orders]
		ifFalse: [store orders select: [ :o | o status = filter ]].! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 19:59'!
renderActionsOn: html
	html div: [
		html anchor callback: [self answer]; with: 'Done'.
	]! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:04'!
renderCancelledStatusFor: anOrder on: html
	html text: 'Cancelled (', (self formatDate: anOrder cancelledDate), ')'.! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/2/2009 17:46'!
renderContentOn: html
	self renderActionsOn: html.
	self renderFilterOn: html.
	self renderOrderListOn: html! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:22'!
renderFilterOn: html
	html form: [ |id|
		id := html nextId.
		html label for: id; with: 'Show: '.
		html select 
			id: id; 
			beSubmitOnChange; 
			beOptional; 
			selected: filter;
			add: #pending; 
			add: #cancelled; 
			add: #shipped;
			labels: [ :o | o asCapitalizedPhrase];
			optionalLabel: 'All';
			callback: [ :value | filter := value]]! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:05'!
renderOrderListOn: html
	html table: [
		html tableRow: [
			html tableHeading: 'Reference'.
			html tableHeading: 'Customer'.
			html tableHeading: 'Items'.
			html tableHeading: 'Total'.
			html tableHeading: 'Date'.
			html tableHeading: 'Status'].
		self orders do: [ :o | html tableRow: [
			html tableData: o reference.
			html tableData: o customer name.
			html tableData: o items count printString.
			html tableData: '$', o items totalInDollars printString.
			html tableData: (self formatDate: o date).
			html tableData: [self perform: ('render', o status capitalized, 'StatusFor:on:') asSymbol with: o with: html].
		]]]! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:01'!
renderPendingStatusFor: anOrder on: html
	html text: 'Pending'.
	html space.
	html anchor callback: [(self confirm: 'Ship Order?') ifTrue: [(WSShipOrderCommand order: anOrder) run]]; with: 'Ship'.
	html space.
	html anchor callback: [(self confirm: 'Cancel Order?') ifTrue: [(WSCancelOrderCommand order: anOrder) run]]; with: 'Cancel'.! !

!WSOrderManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:03'!
renderShippedStatusFor: anOrder on: html
	html text: 'Shipped (', (self formatDate: anOrder shippedDate), ')'.! !

WAComponent subclass: #WSOrderSuccess
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSOrderSuccess class methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 10:03'!
order: anOrder
	^self basicNew
		order: anOrder;
		initialize;
		yourself! !

!WSOrderSuccess methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 10:03'!
order: anOrder
	order := anOrder! !

!WSOrderSuccess methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:31'!
renderContentOn: html
	html heading: 'Order Complete'.
	html paragraph: 'Your order was succesfully placed, and your reference number is: ', order reference.
	html div class: 'nav-buttons'; with: [
		html anchor callback: [self answer]; with: 'Close']! !

WAComponent subclass: #WSProductDetails
	instanceVariableNames: 'product imageViewer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSProductDetails class methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:54'!
for: aProduct
	^self basicNew
		product: aProduct;
		initialize;
		yourself.! !

!WSProductDetails methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:53'!
children
	^Array with: imageViewer.! !

!WSProductDetails methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:52'!
initialize
	super initialize.
	imageViewer := WSProductImageView for: product.! !

!WSProductDetails methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:55'!
product: aProduct
	product := aProduct.! !

!WSProductDetails methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 13:41'!
renderContentOn: html
	html div class: 'product-details'; with: [
		html render: imageViewer.
		html heading level: 2; with: product name.
		html paragraph with: '$', product priceInDollars printString.
		html paragraph with: (product stock > 0 
			ifTrue: [ 'Items in stock: ', product stock printString]
			ifFalse: [ 'Out of stock']).
		html paragraph with: product description.
		html anchor callback: [ self answer ]; with: 'Back'
	].! !

WAComponent subclass: #WSProductEditor
	instanceVariableNames: 'product fields'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSProductEditor class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:49'!
new
	^self product: (WSProduct new).! !

!WSProductEditor class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:49'!
product: aProduct
	^self basicNew
		initializeWithProduct: aProduct;
		initialize;
		yourself.! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 15:19'!
children
	^Array with: fields! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:47'!
initializeWithProduct: aProduct
	self initialize.
	product := aProduct.
	self setupFields.! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 15:20'!
renderContentOn: html
	html form: [
		html render: fields.
		html div: [
			html cancelButton value: 'Cancel'; callback: [ self answer: nil].
			html submitButton value: 'Save'; callback: [ self saveAndAnswer]
	]]! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:28'!
saveAndAnswer
	fields valid ifTrue: [ 
		(WSApplyFormCommand form:fields) run.
		self answer: product]! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 19:12'!
setupFields
	fields := WSForm new.
	
	fields add: (WSField text 
		label: 'Name';
		on: #name of: product;
		beRequired).
	fields add: (WSField money
		label: 'Price';
		on: #price of: product;
		beRequired).
	fields add: (WSField integer
		label: 'Stock Count';
		on: #stock of: product;
		beRequired).
	fields add: (WSField largeText
		label: 'Description';
		on: #description of: product).! !

WAComponent subclass: #WSProductImageView
	instanceVariableNames: 'current product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSProductImageView class methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:54'!
for: aProduct
	^self basicNew
		product: aProduct;
		initialize;
		yourself.! !

!WSProductImageView methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:54'!
initialize
	super initialize.
	current := product preview.! !

!WSProductImageView methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:55'!
product: aProduct
	product := aProduct.! !

!WSProductImageView methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 13:55'!
renderContentOn: html
	product images ifEmpty: [^self].
	html div class: 'image-viewer'; with: [
		html anchor resourceUrl: WSImageLibrary path, current fullsize; with: [self renderImage: current medium on: html].
		html unorderedList: [
		(product images reject: [:i | i = current]) do: [ :i|
			html listItem: [html anchor callback: [ current := i]; with: [self renderImage: i thumbnail on: html]]
	]]]! !

!WSProductImageView methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 09:02'!
renderImage: anImage on: html
	html image resourceUrl: WSImageLibrary path, anImage! !

WAComponent subclass: #WSProductList
	instanceVariableNames: 'products'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSProductList class methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 17:24'!
products: aCollection
	^self basicNew
		products: aCollection;
		initialize.! !

!WSProductList methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 17:24'!
products: aCollection
	products := aCollection
	! !

!WSProductList methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:19'!
renderContentOn: html
	(products select: [:p | p enabled]) 
		do: [ :p| html render: (WSProductPreview for: p on: self)]! !

WAComponent subclass: #WSProductManager
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSProductManager class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:49'!
store: aStore
	^self basicNew
		initializeWithStore: aStore;
		yourself! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:07'!
addProduct
	| p |
	p := self call: WSProductEditor new.
	p ifNotNil: [	store addProduct: p]! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:09'!
deleteProduct: p
	(self confirm: 'Really delete ',p name, '?') ifTrue: [
		store deleteProduct: p	
	]! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:01'!
editProduct: aProduct 
	self call: (WSProductEditor product: aProduct)! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 20:51'!
initializeWithStore: aStore
	self initialize.
	store := aStore! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:24'!
manageImages: aProduct
	self call: (WSImageManager for: aProduct)! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:45'!
renderActionsOn: html
	html div: [
		html anchor callback: [ self addProduct]; with: 'Add Product'.
		html text: ' '.
		html anchor callback: [self answer]; with: 'Done']! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 13:24'!
renderContentOn: html
	self renderStatsOn: html.
	self renderActionsOn: html.
	self renderProductListOn: html.
	html paragraph: [
		html anchor callback: [ self answer ]; with: 'back']! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 10:06'!
renderProductListOn: html
	html table: [
		html tableRow: [
			html tableHeading.
			html tableHeading: 'Name'.
			html tableHeading: 'Price'.
			html tableHeading: 'Actions'	].
		store products do: [ :p| html tableRow: [
			html tableData: [
				p preview ifNotNil: [html image resourceUrl: WSImageLibrary path, p preview thumbnail]
			].		
			html tableData: p name.
			html tableData: p priceInDollars printString.
			html tableData: [ 
				html anchor callback: [ self deleteProduct: p ]; with: 'Delete'.
				html space.
				html anchor callback: [self editProduct: p]; with: 'Edit'.
				html space.
				html anchor callback: [self manageImages: p ]; with: 'Images'.
				html space.
				p enabled 
					ifTrue: [html anchor callback: [p disable]; with: 'Disable']
					ifFalse: [html anchor callback: [p enable]; with: 'Enable']]]]]! !

!WSProductManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:25'!
renderStatsOn: html
	html div: [
		html paragraph: store products size printString, ' products']! !

WAComponent subclass: #WSProductPreviewComponent
	instanceVariableNames: 'preview'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSProductPreviewComponent methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:13'!
initialize
	super initialize.
	preview := WSProductPreview new.
	preview parent: self.! !

!WSProductPreviewComponent methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:13'!
product: aProduct
	preview product: aProduct! !

!WSProductPreviewComponent methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:18'!
renderContentOn: html
	html render:  preview.! !

WAComponent subclass: #WSStoreAdmin
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSStoreAdmin class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 11:51'!
canBeRoot
	^true! !

!WSStoreAdmin methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:57'!
initialize
	super initialize.
	store := self session store.! !

!WSStoreAdmin methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 09:49'!
menu: title callback: aBlock on: html
	html heading level: 2; with: [
	html anchor 
		callback: aBlock; 
		with: title].
! !

!WSStoreAdmin methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 16:04'!
migrateStore
	self session commit: [store migrate].
	self inform: 'Migration Successful'! !

!WSStoreAdmin methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:45'!
renderContentOn: html 
	self 
		menu: 'Manage Products'
		callback: [ self call: (WSProductManager store: store) ]
		on: html.
	self 
		menu: 'Manage Orders'
		callback: [ self call: (WSOrderManager store: store) ]
		on: html.
	self 
		menu: 'Migrate Store'
		callback: [ self migrateStore ]
		on: html.
	html heading
		level: 2;
		with: 
			[ html anchor
				resourceUrl: 'store';
				with: 'Go to Store' ]! !

WAComponent subclass: #WSWizardPage
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

WSWizardPage subclass: #WSBaseAddressPage
	instanceVariableNames: 'fields tempAddress'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSBaseAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:21'!
addressClass
	^WSAddress! !

!WSBaseAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:13'!
children
	^Array with:fields! !

!WSBaseAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:21'!
initialize
	super initialize.
	tempAddress := self addressClass new.
	fields := WSForm new.
	self setupFields! !

!WSBaseAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 22:16'!
setupFields
	fields add: (WSField text 
		label: 'Address Line 1';
		on: #address1 of: tempAddress;
		beRequired).
	fields add: (WSField text 
		label: 'Address Line 2';
		on: #address2 of: tempAddress).
	fields add: (WSField text
		label: 'Suburb / Town';
		on: #locality of: tempAddress).
	fields add: (WSField text
		label: 'State / Province';
		on: #state of: tempAddress;
		beRequired).
	fields add: (WSField text
		label: 'Postcode';
		on: #postcode of: tempAddress;
		beRequired).
	fields add: (WSField text
		label: 'Country';
		on: #country of: tempAddress;
		beRequired).! !

WSBaseAddressPage subclass: #WSCustomerPage
	instanceVariableNames: 'tempCustomer email2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:31'!
email2
	^email2! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:32'!
email2: anEmail
	email2 := anEmail! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:26'!
enabled
	^true! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:11'!
initialize
	tempCustomer := WSCustomer new.	
	super initialize.
	tempCustomer address: tempAddress! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:29'!
renderContentOn: html
	html div class: 'customer-details'; with: fields.	! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:59'!
save
	fields valid 
		ifTrue: [
			fields save.
			model customer: tempCustomer.
			^true]
		ifFalse: [^false]! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:55'!
setupFields
	| email1Field email2Field |
	fields add: (WSField text 
		label: 'Name';
		on: #name of: tempCustomer;
		beRequired).
	email1Field :=  (WSField text 
		label: 'Email';
		on: #email of: tempCustomer;
		beRequired).
	email2Field := (WSField text 
		label: 'Confirm Email';
		on: #email2 of: self;
		beRequired).
	fields add:email1Field.
	fields add: email2Field.
	super setupFields.
	fields addRule: [ :v | email1Field value = email2Field value] withDescription: 'Email addresses don''t match'.! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:31'!
title
	^'Customer Details'! !

!WSCustomerPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:59'!
valid
	^fields valid! !

WSBaseAddressPage subclass: #WSShippingAddressPage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:22'!
addressClass
	^WSShippingAddress! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 20:35'!
enabled
	^model customer notNil! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:24'!
initialize
	super initialize.! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:13'!
onEnter
	model address ifNil: [
		tempAddress name: model customer name.
		tempAddress populateFrom: model customer address.
		fields updateFromModel.
	]! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:33'!
renderContentOn: html
	html div class: 'shipping-address'; with: fields.	! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:41'!
save
	fields valid 
		ifTrue: [
			fields save.
			model address: tempAddress.
			^true]
		ifFalse: [^false]! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:23'!
setupFields
	fields add: (WSField text 
		label: 'Name';
		on: #name of: tempAddress;
		beRequired).
	super setupFields.! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:26'!
title
	^'Shipping Address'! !

!WSShippingAddressPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:40'!
valid
	^model address notNil.! !

WSWizardPage subclass: #WSCartViewPage
	instanceVariableNames: 'cartView'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSCartViewPage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:57'!
children
	^Array with: cartView! !

!WSCartViewPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 13:53'!
enabled
	^true! !

!WSCartViewPage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 15:00'!
initialize
	super initialize.
! !

!WSCartViewPage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 15:01'!
model: anObject
	super model: anObject.
	cartView := WSCartView cart: model items! !

!WSCartViewPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 13:22'!
renderContentOn: html
	html render: cartView! !

!WSCartViewPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 13:19'!
title
	^'Review Order'! !

!WSCartViewPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 13:39'!
valid
	^true! !

WSWizardPage subclass: #WSConfirmOrderPage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:40'!
enabled
	^model address notNil! !

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:37'!
renderAddress: anAddress on: html
	html
		definitionTerm: 'Address';
		definitionData: [
			html text: anAddress address1.
			anAddress address2 ifNotNil: [
				html break; text: anAddress address2.
			].
			html
				text: anAddress locality, ' ', anAddress state, ' ', anAddress postcode; break;
				text: anAddress country]! !

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:40'!
renderContentOn: html
	html div id: 'confirm-order'; with: [
		html div: [self renderOrderSummaryOn: html].			
		html div: [self renderCustomerDetailsOn: html].			
		html div: [self renderShippingOn: html].
	]! !

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:34'!
renderCustomerDetailsOn: html
	html heading level: 2; with: 'Customer Details'.
	html definitionList: [
		html 
			definitionTerm: 'Name';
			definitionData: model customer name;
			definitionTerm: 'Email';
			definitionData: model customer email.
		self renderAddress: model customer address on: html
	]! !

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:39'!
renderOrderSummaryOn: html
	html heading level: 2; with: 'Order'.
	html paragraph: self session cart count printString, ' items, for a total of $', self session cart totalInDollars printString.
! !

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:38'!
renderShippingOn: html
	html heading level: 2; with: 'Shipping To:'.
	html definitionList: [
		html 
			definitionTerm: 'Name';
			definitionData: model address name.
		self renderAddress: model address on: html
	]! !

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 13:19'!
title
	^'Confirm Purchase'! !

!WSConfirmOrderPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:03'!
valid
	^true! !

!WSWizardPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:38'!
enabled
	^false! !

!WSWizardPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:39'!
initialize
	super initialize.! !

!WSWizardPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:38'!
model: anObject
	model := anObject! !

!WSWizardPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:58'!
onEnter! !

!WSWizardPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 14:32'!
save
	"Attempt to save the data on the page, return success or failure"
	^true! !

!WSWizardPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 12:54'!
title
	^self subclassResponsibility.! !

!WSWizardPage methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 15:55'!
valid
	^false! !

WATask subclass: #WSCheckoutProcess
	instanceVariableNames: 'wizard'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Checkout'!

!WSCheckoutProcess methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:21'!
go
	[| order | 
	order := self call: wizard.
	order ifNil: [self answer].
	
	[(WSPlaceOrderCommand store: self store order: order) run ] 
		on: WSOrderError do: [:e | 
			self call: (WSOrderErrorPage error: e).
			wizard goToFirstPage].
		
	self	call: (WSOrderSuccess order: order).
	self answer] repeat! !

!WSCheckoutProcess methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 22:00'!
initialize
	super initialize.
	wizard := WSCheckoutWizard new.! !

!WSCheckoutProcess methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 17:50'!
store
	^self session store! !

!WSCheckoutProcess methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 21:00'!
wizard
	"for testing purposes"
	^wizard! !

!WSCheckoutProcess methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 21:00'!
wizard: aWizard
	"for testing purposes"
	wizard := aWizard! !

WATask subclass: #WSTestOrderWizard
	instanceVariableNames: 'order page'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:19'!
go
	self answer: order! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:58'!
goToFirstPage
	page := 1.! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 21:01'!
initialize
	super initialize.
	page := 2.! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:19'!
order: anOrder
	order := anOrder! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:58'!
page
	^page! !

Object subclass: #WSCommand
	instanceVariableNames: 'transactionProvider'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSCommand commentStamp: 'srh 1/25/2009 21:55' prior: 0!
A WSCommand is a base class for implemting Commands.
A command is a single unit of work within the system, and operates within a transaction.
If a command throws an exception, the transaction will be rolled back.

Instance Variables
	transactionProvider:		<Object>

transactionProvider
	- An object that implements #commit: and #abort.  The default implementation pulls it from the Seaside session, and assumes it's available as #magmaSession
!

WSCommand subclass: #WSApplyFormCommand
	instanceVariableNames: 'form'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSApplyFormCommand class methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:20'!
form: aForm
	^self basicNew
		initializeWithForm: aForm;
		yourself! !

!WSApplyFormCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:29'!
do
	form save.! !

!WSApplyFormCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:20'!
initializeWithForm: aForm
	form := aForm.
	self initialize.! !

WSCommand subclass: #WSCancelOrderCommand
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSCancelOrderCommand class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:53'!
order: anOrder
	^self basicNew
		initializeWithOrder: anOrder;
		yourself! !

!WSCancelOrderCommand methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:57'!
do
	order cancel.! !

!WSCancelOrderCommand methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:55'!
initializeWithOrder: anOrder
	self initialize.
	order := anOrder! !

!WSCommand class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:15'!
new
	self shouldNotImplement! !

!WSCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:05'!
do
	"Override this to actually do something"! !

!WSCommand methodsFor: 'initialization' stamp: 'srh 1/25/2009 21:59'!
initialize
	super initialize.
	transactionProvider := WACurrentSession value magmaSession.! !

!WSCommand methodsFor: 'processing' stamp: 'srh 1/26/2009 00:19'!
run
	[transactionProvider
		commit: [self do]]
		on: Error
		do: [:e | 
			transactionProvider abort.
			e signal]! !

WSCommand subclass: #WSPlaceOrderCommand
	instanceVariableNames: 'store order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSPlaceOrderCommand class methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:22'!
store: aStore order: anOrder
	^self basicNew
		initializeWithStore: aStore order: anOrder;
		yourself! !

!WSPlaceOrderCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:39'!
do
	store placeOrder: order! !

!WSPlaceOrderCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:23'!
initializeWithStore: aStore order: anOrder
	store := aStore.
	order := anOrder.
	self initialize.
! !

WSCommand subclass: #WSProductCommand
	instanceVariableNames: 'product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

WSProductCommand subclass: #WSAddImageCommand
	instanceVariableNames: 'image'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSAddImageCommand class methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 13:36'!
product: aProduct image: anImage
	^self basicNew
		initializeWithProduct: aProduct image: anImage;
		yourself! !

!WSAddImageCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 13:37'!
do
	product addImage: image! !

!WSAddImageCommand methodsFor: 'initialization' stamp: 'srh 1/26/2009 13:36'!
initializeWithProduct: aProduct image: anImage
	image := anImage.
	self initializeWithProduct: aProduct.
	! !

WSProductCommand subclass: #WSDeleteImageCommand
	instanceVariableNames: 'image'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSDeleteImageCommand class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:17'!
product: aProduct image: anImage
	^self basicNew
		initializeWithProduct: aProduct image: anImage;
		yourself! !

!WSDeleteImageCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:19'!
do
	product removeImage: image! !

!WSDeleteImageCommand methodsFor: 'initialization' stamp: 'srh 1/25/2009 23:03'!
initializeWithProduct: aProduct image: anImage
	image := anImage.
	self initializeWithProduct: aProduct.
	! !

!WSProductCommand methodsFor: 'initialization' stamp: 'srh 1/25/2009 22:16'!
initializeWithProduct: aProduct
	product := aProduct.
	self initialize.
! !

WSProductCommand subclass: #WSSetPreviewCommand
	instanceVariableNames: 'image'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSSetPreviewCommand class methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 13:36'!
product: aProduct image: anImage
	^self basicNew
		initializeWithProduct: aProduct image: anImage;
		yourself! !

!WSSetPreviewCommand methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 13:37'!
do
	product preview: image! !

!WSSetPreviewCommand methodsFor: 'initialization' stamp: 'srh 1/26/2009 13:36'!
initializeWithProduct: aProduct image: anImage
	image := anImage.
	self initializeWithProduct: aProduct.
	! !

WSCommand subclass: #WSShipOrderCommand
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Commands'!

!WSShipOrderCommand class methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:53'!
order: anOrder
	^self basicNew
		initializeWithOrder: anOrder;
		yourself! !

!WSShipOrderCommand methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:57'!
do
	order ship! !

!WSShipOrderCommand methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:54'!
initializeWithOrder: anOrder
	self initialize.
	order := anOrder! !

Object subclass: #WSObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

WSObject subclass: #WSAddress
	instanceVariableNames: 'address1 address2 postcode locality state country'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 17:17'!
address1
	^address1! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:02'!
address1: anAddress
	address1 := anAddress.! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:05'!
address2
	^address2! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:05'!
address2: anAddress
	address2 := anAddress.! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:07'!
country
	^country! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:07'!
country: aCountry
	country := aCountry! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:07'!
locality
	^locality! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:08'!
locality: aLocality
	locality := aLocality! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 21:12'!
populateFrom: anAddress
	(WSAddress selectors reject: [ :s | s endsWith: ':']) do: [ :s |
		self perform: s asMutator with: (anAddress perform: s)]! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:08'!
postcode
	^postcode! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:08'!
postcode: aPostcode
	postcode := aPostcode! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:08'!
state
	^state! !

!WSAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 18:10'!
state: aState
	state := aState! !

WSAddress subclass: #WSShippingAddress
	instanceVariableNames: 'name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSShippingAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 14:43'!
name
	^name! !

!WSShippingAddress methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 14:46'!
name: aName
	name := aName! !

WSObject subclass: #WSCart
	instanceVariableNames: 'items'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:42'!
add: aProduct
	items add: aProduct! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 13:23'!
anySatisfy: aBlock
	^items anySatisfy: aBlock! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 15:04'!
count
	^items size! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 09:50'!
do: aBlock
	items do: aBlock! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:56'!
empty
	^(items size > 0) not! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:48'!
initialize
	items := OrderedCollection new.! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:50'!
items
	^items clone! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 14:20'!
remove: aProduct
	items remove: aProduct.! !

!WSCart methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:51'!
totalInDollars
	|t|
	t := items inject: 0 into: [:a :i| a + i price].
	^(t / 100) asFloat.! !

WSObject subclass: #WSCustomer
	instanceVariableNames: 'email name phone address'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:51'!
address
	^address! !

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:53'!
address: billingAddress
	address := billingAddress! !

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:50'!
email
	^email! !

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:52'!
email: anEmailAddress
	email := anEmailAddress! !

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:50'!
name
	^name! !

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:53'!
name: aName
	name := aName! !

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:51'!
phone
	^phone! !

!WSCustomer methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:52'!
phone: aPhoneNumber
	phone := aPhoneNumber! !

WSObject subclass: #WSImage
	instanceVariableNames: 'baseName'
	classVariableNames: 'Medium Thumb Extension'
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSImage class methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:41'!
initialize
	super initialize.
	Thumb := 50@50.
	Medium := 200@200.
	Extension := '.jpg'! !

WSImage subclass: #WSDummyImage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestResources'!

!WSDummyImage class methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:31'!
baseName: aName
	^self new
		baseName: aName;
		yourself.! !

!WSDummyImage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:27'!
baseName: aString
	baseName := aString! !

!WSImage class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:42'!
fromStream: aStream
	^self basicNew
		initialize;
		generateImagesFrom: (ImageReadWriter formFromStream: aStream);
		yourself.
	! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:33'!
fullsize
	^ baseName, '-full' , Extension! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:33'!
generateImagesFrom: aForm.
	(aForm scaledToSize: Thumb) writeJPEGfileNamed: self path, self thumbnail.
	(aForm scaledToSize: Medium) writeJPEGfileNamed: self path, self medium.
	aForm writeJPEGfileNamed: self path, self fullsize.! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:33'!
initialize
	super initialize.
	baseName := UUID new printString! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:33'!
medium
	^ baseName, '-med' , Extension! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:01'!
migrate
	baseName class = UUID ifTrue: [
		baseName := baseName printString.	
	]! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 08:32'!
path
	^'files/'! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:32'!
thumbnail
	^ baseName, '-thumb' , Extension! !

!WSObject methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 09:42'!
migrate
	"Initialize new ivars added since the object was saved"
! !

WSObject subclass: #WSOrder
	instanceVariableNames: 'items address customer status id orderDate shippedDate cancelledDate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:35'!
address
	^address! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:37'!
address: aShippingAddress
	address := aShippingAddress! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:18'!
cancel
	status = #new ifFalse: [
		items do: [ :p | p stock: p stock + 1].
		status := #cancelled..
		cancelledDate := DateAndTime now.
	]! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 20:34'!
cancelledDate
	^cancelledDate! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:35'!
customer
	^customer! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:36'!
customer: aCustomer
	customer := aCustomer! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 20:32'!
date
	^orderDate! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 09:00'!
initialize
	super initialize.
	status := #new! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:35'!
items
	^items! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 16:36'!
items: aCollectionOfProducts 
	items := aCollectionOfProducts! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:18'!
migrate
	super migrate.
	orderDate ifNil: [orderDate := DateAndTime now].! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 20:43'!
placeOrder: orderId
	self items do: [ :p | p stock: p stock - 1].
	(self items anySatisfy: [ :p | p stock < 1]) 
		ifTrue: [ WSOutOfStockError new signal ].
	id := orderId.
	status := #pending.
	orderDate := DateAndTime now.! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 12:13'!
reference
	^id! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 12:13'!
reference: anId
	id := anId! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:19'!
ship
	status = #pending ifFalse: [ Error signal: 'Can only ship pending orders'].
	status := #shipped.
	shippedDate := DateAndTime now.! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 20:33'!
shippedDate
	^shippedDate! !

!WSOrder methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 08:59'!
status
	^status! !

WSObject subclass: #WSProduct
	instanceVariableNames: 'name description price images preview enabled stock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:20'!
addImage: anImage
	images add: anImage.
	images size = 1 ifTrue: [preview := anImage]! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:29'!
description
	^description! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:30'!
description: aDescription
	description := aDescription.! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 09:58'!
disable
	enabled := false! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 09:50'!
enable
	enabled := true! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 09:50'!
enabled
	^enabled! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 21:22'!
images
	^images! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 09:51'!
initialize
	images := OrderedCollection new.
	enabled := false.
	stock := 0.
	! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:02'!
migrate
	images do: [ :i | i migrate]! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:53'!
name
	^name.! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:53'!
name: aName
	name := aName.! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:19'!
preview
	^preview! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:24'!
preview: anImage
	(images includes: anImage) ifFalse: [
		self error: 'Preview image must be one of the product''s images'
	].
	preview := anImage! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:32'!
price
	^price! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:32'!
price: priceInCents
	price := priceInCents! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:20'!
priceInDollars
	^(price / 100) asFloat! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:22'!
removeImage: anImage
	images remove: anImage.
	preview = anImage ifTrue: [
		preview := images isEmpty ifTrue: [nil] ifFalse: [images first]]! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 09:52'!
stock
	^stock! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 09:52'!
stock: aNumber
	stock := aNumber! !

WSObject subclass: #WSStore
	instanceVariableNames: 'products orders orderId'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:48'!
addProduct: aProduct
	products add: aProduct.! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:45'!
deleteProduct: aProduct
	products remove: aProduct! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 12:09'!
initialize
	super initialize.
	products := OrderedCollection new.
	orders := OrderedCollection new.
	orderId := 0.! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:20'!
migrate
	"Initialize new ivars added since the object was saved"
	orderId ifNil: [orderId := 0].
	orders ifNil: [ orders := OrderedCollection new ].
	products do: [:p | p migrate].
	orders do: [:o | o migrate].
! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 09:40'!
nextOrderId
	orderId := orderId + 1.
	^orderId printString.! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 09:54'!
orders
	^OrderedCollection new addAll: orders! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 09:39'!
placeOrder: anOrder
	anOrder placeOrder: self nextOrderId.
	orders add: anOrder.! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:49'!
products
	^OrderedCollection new addAll: products.! !

Object subclass: #WSProductPreview
	instanceVariableNames: 'product parent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSProductPreview class methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:27'!
for: aProduct on: parent
	^self basicNew 
		product: aProduct; 
		parent: parent;
		initialize;
		yourself.! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:48'!
initialize
	super initialize.! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:26'!
parent: aComponent
	parent := aComponent! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:48'!
product: aProduct
	product := aProduct.! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:20'!
renderOn: html
	html div class: 'product-preview'; with: [
		html anchor callback: [parent call: (WSProductDetails for: product)]; with: [
			product preview ifNotNil: [html image resourceUrl: WSImageLibrary path, product preview thumbnail].
		].
		html paragraph: '$', product priceInDollars printString.
		product stock > 0 
			ifTrue: [html paragraph: [html anchor callback: [parent session cart add: product]; with: 'Add to Order']]
			ifFalse: [ html paragraph: 'Out of stock'].
		html heading level: 3; with: [
				html anchor callback: [ parent call: (WSProductDetails for: product) ]; with: product name]].! !

Object subclass: #WSRule
	instanceVariableNames: 'rule message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSRule class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:01'!
rule: aBlock message: aMessage
	^self basicNew
		rule: aBlock;
		message: aMessage;
		initialize;
		yourself.! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:02'!
message
	^message! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:02'!
message: aString
	message := aString! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:02'!
rule
	^rule! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:01'!
rule: aBlock
	rule :=  aBlock! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:04'!
testRule: value
	^rule value: value! !

Object subclass: #WSTestingStore
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestResources'!

!WSTestingStore class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:36'!
new
	^self basicNew
		initialize;
		yourself.! !

!WSTestingStore class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:37'!
store
	^self new store! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 2/2/2009 17:40'!
addOrders
	store placeOrder: (WSOrder new
		customer: (WSCustomer new
			name: 'Customer1';
			email: 'cust1@example.com';
			address: (WSAddress new
				address1: 'o1 Address Line 1';
				address2: 'o1 Address Line 2';
				locality: 'o1 Suburb';
				state: 'o1 State';
				postcode: 'o1 1234';
				country: 'Australia';
				yourself);
			yourself);
		address: (WSShippingAddress new
			name: 'o1 recipient';
			address1: 'o1 Ship address 1';
			address2: 'o1 Ship address 2';
			locality: 'o1 Suburb';
			state: 'o1 State';
			postcode: 'o1 1234';
			country: 'o1 Australia';
			yourself);
		items: (WSCart new
			add: store products first;
			add: (store products at: 4);
			yourself)).

	store placeOrder: (WSOrder new
		customer: (WSCustomer new
			name: 'Customer2';
			email: 'cust2@example.com';
			address: (WSAddress new
				address1: 'c2 Address Line 1';
				address2: 'c2 Address Line 2';
				locality: 'c2 Suburb';
				state: 'State';
				postcode: '1234';
				country: 'Australia';
				yourself);
			yourself);
		address: (WSShippingAddress new
			name: 'recipient';
			address1: 'Ship address 1';
			address2: 'Ship address 2';
			locality: 'Suburb';
			state: 'State';
			postcode: '1234';
			country: 'Australia';
			yourself);
		items: (WSCart new
			add: store products first;
			add: store products first)).
	store orders second cancel.
	store placeOrder: (WSOrder new
		customer: (WSCustomer new
			name: 'Customer1';
			email: 'cust1@example.com';
			address: (WSAddress new
				address1: 'Address Line 1';
				address2: 'Address Line 2';
				locality: 'Suburb';
				state: 'State';
				postcode: '1234';
				country: 'Australia';
				yourself);
			yourself);
		address: (WSShippingAddress new
			name: 'recipient';
			address1: 'Ship address 1';
			address2: 'Ship address 2';
			locality: 'Suburb';
			state: 'State';
			postcode: '1234';
			country: 'Australia';
			yourself);
		items: (WSCart new
			add: store products first;
			add: store products first)).
		store orders last ship.! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 2/2/2009 17:43'!
addProducts
	store addProduct: (WSProduct new
		name: 'Test product 1';
		description:  'Product description 1';
		price: 12345;
		stock: 5;
		enable;
		addImage: (WSDummyImage baseName: 'p1-i1');
		addImage: (WSDummyImage baseName: 'p1-i2');
		addImage: (WSDummyImage baseName: 'p1-i3');		
		yourself).

	store addProduct: (WSProduct new
		name: 'Test product 2';
		description:  'Product description 2';
		price: 33000;
		stock: 0;
		enable;
		addImage: (WSDummyImage baseName: 'p2-i1');
		yourself).
	store addProduct: (WSProduct new
		name: 'Test product 3';
		description:  'Product description 3';
		price: 44000;
		stock: 0;
		addImage: (WSDummyImage baseName: 'p3-i1');
		disable;
		yourself).
		
	store addProduct: (WSProduct new
		name: 'Test product 4';
		description:  'Product description 4';
		price: 12345;
		stock: 4;
		enable;
		addImage: (WSDummyImage baseName: 'p4-i1');
		addImage: (WSDummyImage baseName: 'p4-i2');
		addImage: (WSDummyImage baseName: 'p4-i3');		
		yourself).! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 1/31/2009 18:53'!
initialize
	super initialize.
	store := WSStore new.
	self addProducts.
	self addOrders.
! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:33'!
store
	^store! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:00'!
tearDown
	session disconnect; closeRepository.! !

Object subclass: #WSTransactionalStub
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestResources'!

!WSTransactionalStub methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:35'!
abort! !

!WSTransactionalStub methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:35'!
commit: aBlock
	aBlock value! !

WAMagmaSession subclass: #WSSession
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

WSSession subclass: #TestSiteSession
	instanceVariableNames: 'cart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestSite'!

!TestSiteSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:48'!
cart
	^cart! !

!TestSiteSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:47'!
initialize
	super initialize.
	self resetCart! !

!TestSiteSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:48'!
resetCart
	cart := WSCart new! !

!WSSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 22:03'!
store
	store ifNil: [store := self magmaSession root at: #store].
	^store! !

WSSession subclass: #WSTestSession
	instanceVariableNames: 'cart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests-UI'!

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:49'!
cart
	^cart! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:13'!
cart: aCart
	cart := aCart! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 10:16'!
commit: aBlock
	aBlock value! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 10:18'!
initialize
	super initialize.
	self setUpStore.
	self resetCart! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:36'!
magmaSession
	^magmaSession ifNil: [magmaSession := WSTransactionalStub new]! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:56'!
magmaSession: aSession
	magmaSession := aSession! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 10:18'!
resetCart
	cart := WSCart new.! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 20:27'!
setUpStore
	store := WSStore new.
	store addProduct: (WSProduct new
		name: 'Test product 1';
		description:  'Product description 1';
		price: 12345;
		stock: 2;
		enable;
		yourself).
	store addProduct: (WSProduct new
		name: 'Test product 2';
		description:  'Product description 2';
		price: 33000;
		stock: 0;
		enable;
		yourself).
	store addProduct: (WSProduct new
		name: 'Test product 3';
		description:  'Product description 3';
		price: 44000;
		stock: 0;
		disable;
		yourself).! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 12:06'!
store: aStore
	store := aStore! !

Error subclass: #WSOrderError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

WSOrderError subclass: #WSOutOfStockError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!
WSImage initialize!
